@@ -2,6 +2,7 @@
 from unittest import TestCase
 
 import pytest
+
 from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 
 
@@ -10,14 +11,17 @@ from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 # pass, by inheritance from define_tests.TheTests
 class YandexPDDProviderTests(TestCase, IntegrationTestsV2):
     """TestCase for Yandex"""
-    provider_name = 'yandex'
-    domain = 'capsulecd.com'
+
+    provider_name = "yandex"
+    domain = "capsulecd.com"
 
     def _filter_headers(self):
         """Sensitive headers to be filtered."""
-        return ['Authorization', 'PddToken']
+        return ["Authorization", "PddToken"]
 
     # TODO: enable the skipped tests
     @pytest.mark.skip(reason="new test, missing recording")
-    def test_provider_when_calling_update_record_should_modify_record_name_specified(self):
+    def test_provider_when_calling_update_record_should_modify_record_name_specified(
+        self,
+    ):
         return
